<?php	  
	/** 
	* This page lists all the existing carriers (and allows multiple selection).
	* Three pages can be targeted from here:
	*  - carriers_data.php: if the user clicks on one table's row or select "new record" (single selection)
	*  - carriers_confirm.php: if the user chooses the "modify" or "delete" option (multiple selection)
	*  - carriers_search.php: open the research page (no data are passed to the search page)
	*  In the first case data are passed through the HTTP request (GET method), in the second case data are passed
	*  using the POST method (as INPUT fields of the HTML form).
	*
	* TARGETING: the "$target" variable is used to distinguish the user "logged in" from the "browsed" user.
	* - If the user is a normal user we always have "$target == $reference" (see the "session_header.php" page).
	* - If the user is an administrator the "$target" identifies the user being managed by the administrator
	* 	(target is set to -1 if the administrator is not focusing on a particular user)
	*/

	// 1. Including resources
	include '../include/session_header.php' ; 	// Including pages that take care of the session and paging  
	include '../include/database_header.php' ;	// Managing database connections  
	include '../include/users_DAO.php';			// Including pages managing the users	 table (DBA layer)  
	include '../include/carriers_DAO.php' ;		// Including pages managing the carriers table (DBA layer)  
	include '../include/display_header.php' ;	// Defining layout, images and loading the left menu  
	// See also "carriers_labels.php", include below
	
	// 2. Setting page parameters
	$carriersName 	= getCarriersHeaders() ;
	$isAdmin 		= ($_SESSION[$logStatus] == 0) ;

	// 3. Recognizing the view mode selected by the user
	// If we arrived from the search page, we retrieve the search parameters
	$searchQuery = searchCarriers() ;
	// If we arrived from the other pages, we check the target customer (only for administrators)
	if ($isAdmin) {
		if (isset($_GET['reset'])) 		$_SESSION[$target] = - 1 ;  
		if (isset($_GET['customer'])) 	$_SESSION[$target] = $_GET['customer'] ;
	}
	// Now setting filters
	if (isset($_SESSION[$target])) if ($_SESSION[$target] > 0) {
		$filter = "(recipient = '$_SESSION[$target]')" ;
		if ($searchQuery != "") $searchQuery .= " AND " . $filter ;
		else 					$searchQuery = $filter ;
	}
           
	// 4. Customizing table layout
	$delta 		= 20 ;
	$columns 	= 8 ;
	include '../include/carriers_labels.php' ;
  
	// 5. Formatting page for navigation: see "session_header.php"
	formatPage(0, $searchQuery, "carriers") ;
	$nextPage 		= (($pageNumber + 1) < $lastPage)?($pageNumber + 1):$lastPage ;
	$previousPage 	= (($pageNumber - 1) > 0)?($pageNumber - 1):1 ;
	$recordSet 		= getCarriersList($searchQuery, $maxLimit, $offset) ;
	$rows 			= mysql_num_rows($recordSet) ;
?>  

<script language="JavaScript">
// User actions (page bottom)
function goToPage(number) {
	if (number == 1) { window.location.href = "carriers_data.php?code=0" ; 	}
	if (number == 2) { window.location.href = "carriers_search.php" ; 		}
}
// User actions (page bottom)
function postForm(number) {
	if (number == 1) { document.selection.quest.value = number ; }
	if (number == 2) { document.selection.quest.value = number ; }
	document.selection.submit() ;
	//console.log("Quest value = " + document.selection.quest.value) ;
}
// Appending the users CSS at run-time
linkElement 		= document.createElement("link") ;
linkElement.rel 	= "stylesheet" ;
linkElement.href 	= "../css/carriers.css" ; 
document.head.appendChild(linkElement) ;
// jQuery section
$(document).ready( function() {
	// Adding zebra crossing
	$('#carriers_table tr:odd').addClass('td_odd') ;
	$('#carriers_table tr:even').addClass('td_even') ;
<?php if ($isAdmin) {	 	?>	
	// Highlighting the whole row only when NOT hover user lookup fields.
	$('#carriers_table td:not(.lookup)').hover( 
<?php } else {				?>		
	// Always highlighting the whole row (not administrator)
	$('#carriers_table td').hover( 
<?php } 					?>		
		function() { $(this).parent('tr').addClass		('carrier_half_row ') ;	} , 	// MouseEnter handler
		function() { $(this).parent('tr').removeClass	('carrier_half_row ') ;	}		// MouseLeaves handler
	) ;
}) ;
// jQuery: select/unselect all
function toggleChecked(status) {
	$('.checkbox').each( function() {
		$(this).attr('checked', status) ;
	}) ;
	if (status) $('.checkall_label').text('Deseleziona tutti') ;
	else $('.checkall_label').text('Seleziona tutti') ;
} ;
</script>

<?php
	// 4. Printing table (if data are available)
	if ($rows > 0) {
?>

	<form name="selection" action="carriers_confirm.php" method="post">
	
	<div id="carriers_table">
	<table border="0px">
	  <tr>
	  <td class='checkall'><input type="checkbox" onclick="toggleChecked(this.checked);"></td>
	  <td class="checkall_label" colspan="3">Seleziona tutti</td>
	  <td class="table_caption" colspan="<?php print ($columns - 1) ?>">ELENCO <?php print $labelTitle ; ?></td>
	  </tr><tr>
	  
<?php  
	// PRINTING USERS TABLE
    // 1. Printing table headers, assigning "td width" considering field's length from the database
    print "\t<td class='td_carriers_header'>Sel.</td>\n" ;
    foreach ($carriersName as $index => $caption) {
        $width = $delta*($carriersWidth[$index]) ;
        print "\t<td width='$width px' class='td_carriers_header'>$caption</td>\n" ;
		// Keep for testing or debug
        //print "\t<td width='$width px' class='td_carriers_header'>$index-$carriersWidth[$index]</td>\n" ;
    }
    print "\t<td Class='td_carriers_header'>Status</td>\n" ;
    print "</tr>" ;
    // 2. Printing table data
    $line = 0 ;
    while ($row = mysql_fetch_array($recordSet, MYSQL_ASSOC)) {
		$index = 0 ;
		$line += 1 ;
		// 2.1 Printing first special column (checkbox)
		// Remark: the setting MYSQL_ASSOC is case-sensitive (with respect of the SQL statement)
		$code = $row["shipment_nr"] ;
		print "<tr class='carrier_row'>\n" ;
		print "\t<td><input type='checkbox' class='checkbox' name='record$code'></td>\n" ;
		// 2.2 Printing all other columns (actual values from database)
		foreach ($row as $value) {
			$width = $delta*($carriersWidth[$index]) ;
			if (isset($carriersName[$index])) {
				// If necessary formatting data-time fields
				if ($carriersType[$index] == "date") $value = formatDate($value) ; 
				// 2.2.a Printing look-up reference to the USERS table
				if (($carriersName[$index] == "Mittente") || ($carriersName[$index] == "Destinatario")) {
					$textValue = getCustomerName($value) ;
					if ($isAdmin) 	{
						print "\t<td class='lookup' width='$width px'>" ;
						print "<a href='../users/users_data.php?code=$value' title='Scheda cliente'>$textValue</a>" ;
					} else {
						print "\t<td width='$width px'>" ;
						print "<a href='carriers_data.php?code=$code'>$textValue</a>" ;
					}
					print "</td>\n" ;
				// 2.2.b Printing all other fields (default option)
				} else {
					print "\t<td width='$width px'>" ;
					print "<a href='carriers_data.php?code=$code'>$value</a>" ;
					print "</td>" ;
				}
			}
			$index += 1 ;
		}
		// 2.3 Calculating STATUS for current row
		$delivered 	= formatDate($row["delivery_date"]) ;
		$pendent 	= isDelivered($delivered) ;
		$textValue 	= ($pendent == 1) ? "Attesa" : "OK" ;
		$show_class	= ($pendent == 1) ? "waiting" : "done" ;
		print "<td><a href='carriers_data.php?code=$code'><span class='$show_class'>$textValue</span></a></td>\n";
		print "</tr>\n";
    } // End of "while"
?>

  </table>
  </div> <!-- End of carriers table -->
  
<div class="table_nav">
<span>Spedizioni <?php print $rows; ?> di <?php print $records; ?></span>
<span class="nav_footer">Pagina <?php print $pageNumber; ?> di <?php print $lastPage; ?></span>
<nav class="page_nav">
<?php 
	// Page to be shown before and after current page
	$range = 4 ;
	if ($pageNumber > 1) print "<a class='nav_link_prev' href='carriers_list.php?page=$previousPage'>Indietro</a>" ;
	$start_page	= ($pageNumber > $range ) ? ($pageNumber - $range) : 1 ;
	$end_page	= (($pageNumber + $range) < $lastPage) ? ($pageNumber + $range) : $lastPage ;
	print "<div class='nav_links'>" ;
	for ($i = $start_page ; $i <= $end_page ; $i++) {
		$style = "" ;
		if ($i == $pageNumber) $style = "class='current_page'" ;
		print "<a $style href='carriers_list.php?page=$i'>$i</a>\n" ;
	} 
	print "</div>" ;
	if ($pageNumber < $lastPage) print "<a class='nav_link_next' href='carriers_list.php?page=$nextPage'>Avanti</a>" ;
?>
</nav>
</div>

<?php

  } // End of "if ($rows > 0)"
  else {
    print "<p class='td_carriers_title'>RISULTATI DELLA RICERCA</p>\n" ;
    print "<br/>\n" ;
    print "<p class='td_carriers_title'>Nessuna spedizione soddisfa i parametri della ricerca</p>\n" ;
    print "<br/><br/>\n" ;
  }
  
  // 5. Releasing resources (see the "database_header.php" page)
  releaseAll();
  
  // 6. Selecting layout of the bottom menu (next nav element)
  if ($isAdmin)   	$nav_class = "carrier_nav" ;
  else				$nav_class = "carrier_user_nav" ;
?>

<br/>

<!-- If the target is "carriers_confirm.php", data are passed within the form -->
<input type="hidden" name="quest" value="0">

<nav class="<?php echo $nav_class ?>">
<table>
<?php if ($isAdmin) {	?>
  <tr>
	<td class="td_carriers_action">
	<input type="button" onclick="goToPage(1)" value="Inserisci <?php print $label_01 ; ?>" title="Inserisci nuovo <?php print $label_01 ; ?>">
	</td>
<?php 				}	?>
	<td class="td_carriers_action">
	<input type="button" onclick="postForm(1)" value="Modifica <?php print $label_01 ; ?>" title="Modifica i dati di un <?php print $label_01 ; ?>">
	</td>
<?php if ($isAdmin) {	?>	
	<td class="td_carriers_action">
	<input type="button" onclick="postForm(2)" value="Cancella <?php print $label_01 ; ?>" title="Cancella un <?php print $label_01 ; ?>">
	</td>
<?php 				}	?>
	<td class="td_carriers_action">
	<input type="button" onclick="goToPage(2)" value="Ricerca <?php print $label_01 ; ?>" title="Cerca un <?php print $label_01 ; ?>">
	</td>
  </tr>
</table>
</nav>

</form>

<?php
if ($searchQuery != "") {
	echo "<p class='another_search centered' style='WIDTH:200px;'>" ;
	echo "<a href='carriers_search.php'>Prova con un'altra ricerca</a>" ;
	echo "</p>" ;
}
?>

<?php include '../include/display_footer.php'; ?>