<?php
	/**
	* This is the page that manages authentication into the system.
	* The user authentication could also be specified in a session variable (see SSO below):
	* if this is the case, this page  implements a "proxy separation", storing the result of
	* authentication into following variables:
	*
	* - The "logStatus" session variable (0 = admin, 1 = user)
	* - The "reference" session variable (the code number of the customer)
	*/

	// SKIPPING AUTHENTICATION CHECK: when we include the "session_header.php", such page will check if the
	// user has ALREADY been authenticated, and if not it forward action to the login (or guest) page.
	// Setting this variable we'll skip that check in the "session_header.php" page, since we are going to
	// execute such check here. See the bottom of the "session_header.php" page for details.
	define('FIRST_LOGIN', true) ;
	
	// Page settings
	$root 		= '../' ;							// Reference to absolute position of this page
	$my_debug	= false ;							// We avoid the "debug" indentifier to avoid confusion with included pages

	// SSO (SINGLE-SIGN-ON) ENVIRONMENT: used when login is received outside this site (see "_index.php")
	$userCode 	= "id_user" ;
	
	// INCLUDING RESOURCES
	include $root.'include/session_header.php' ;	// Initializing environment and checking authentication
	include $root.'include/database_header.php' ;	// Managing database connections
	include $root.'include/users_DAO.php';			// Implementing the users DAO

/***********************************************************************************************/
/**********************				MAIN BODY			****************************************/
/***********************************************************************************************/

	// Optional: used to emulate login from external authentication (Single Sign On)
	// Remark: the SSO system is emulated by the "_index.php" page
	if (isset($_GET['user'])) {
		setSingleSignOn($_GET['user']) ;
		setSessionVars() ;
	}

	// Actual code used when the SSO (Single Sign On) system is used
	if (isset($_SESSION[$userCode])) setSessionVars() ;

	// Actual code used when coming from inner authentication (not SS0)
	if (isset($_POST['submit']) && $_POST['submit']=='Entra') checkUser() ;

	// Forwarding action to the home page
	if (!$my_debug) {
		header("Location:home.php") ;
		exit ;							// This line should not be executed (imho)
	}

/***********************************************************************************************/
/**********************			AUTHENTICATION			****************************************/
/***********************************************************************************************/

	/**
	* Used to authenticate the user when coming from "inner login" system (see "home.php" page).
	*
	* Current implementaion relies on a query like: 
	* 	SELECT user_id, login, pwd FROM users WHERE login = '<posted login>'
	* and then comparing retrieved password with md5('<posted password>').
	* An alternative could be using next query:
	*	SELECT user_id, login FROM users WHERE login='<posted login>' AND password=md5('<posted password>')
	* and then assuming that everything is ok if the query return at least one row
	*/
	function checkUser() {

		// Error and debug management
		$err = array();
		global $my_debug ;

		// Server-side validation
		if (!$_POST['login'] || !$_POST['password']) $err[] = 'E\' necessario compilare tutti i campi!' ;

		if (!count($err)) {

			// Retrieving data posted by the "home.php" page
			$rememberMe	= 0 ;
			$login 		= "" ;
			$password 	= "" ;
			if (isset($_POST['login'])) 		$login 		= mysql_real_escape_string( $_POST['login'] 	) ;
			if (isset($_POST['password']))		$password 	= mysql_real_escape_string( $_POST['password']	) ;
			// Remark: it's necessary to cast the POST variable to avoid further errors by next pages or checks
			if (isset($_POST['rememberMe'])) $_POST['rememberMe'] = (int) $_POST['rememberMe'] ;
			if ($my_debug) echo ($login." - ".$password." - ".$_POST['rememberMe']."<br/>") ;

			// Retrieving database data: id - login - encrypted password
			$user = getUserData($login) ;
			if ($my_debug) echo ("Dati utente: " . $user[0] . " - " . $user[1] . " - "  . $user[2] . "<br/>") ;

			// Comparison of post data with database data
			if ( ($user[2] == md5($password) ) && ($user[0] > 0)) {
				setSessionVars($user[0]) ;
			} else {
				// New code
				$err[]='Wrong username and/or password!';
				include 'bad_data.php';
				die() ;
			}

		} // End if (!count($err))...
		
		// Save the error messages in the session
		if ($err) $_SESSION['msg']['login-err'] = implode('<br/>', $err) ;
		
	} // End of checkUser() function

	/**
	* Authenticate using custom authentication: "admin" or "user", where different users are recognized.
	* 
	* REMARK: remember in the "global" section all the variables defined in the "session_header.php" page!
	*/
	function setSessionVars() {

		global $userCode ;														// The user ID we received from SSO (optional)
		global $logStatus, $reference, $loggedName, $target, $phRemember ;		// The variables we set here

		// Getting argument (if present)
		$args = func_get_args() ;
		if (count($args) > 0) $user_id = $args[0] ;

		// Setting default values
		$_SESSION[$logStatus] 	= -1 ;
		$_SESSION[$reference] 	= -1 ;
		// If the user argument is not defined, we assume we are using SSO
		if ( !isset($user_id) && isset($_SESSION[$userCode]) ) $user_id = $_SESSION[$userCode] ;
		
		// TODO: refactor this accessing userVO, and avoiding to execute another query!
		$admin = isAdmin($user_id) ;
		
		// Setting role-oriented session variables
		if ($admin == 1) {
		  $_SESSION[$logStatus] = 0 ;
		  $_SESSION[$target] 	= -1 ;
		}
		elseif ($admin == 0) {
		  $_SESSION[$logStatus] = 1 ;
		  $_SESSION[$target] 	= $user_id ;
		}
		
		// Getting DAO data
		// TODO: improve this using VO persistence from DAO
		$customerData = mysql_fetch_array(getCustomer($user_id), MYSQL_BOTH) ;
		
		// Setting common session variables
		$_SESSION[$reference] 	= $user_id ;
		$_SESSION[$loggedName]	= $customerData[1] ;
		$_SESSION[$phRemember] 	= $_POST['rememberMe'] ;
		// We need this cookie only for the current session (see "session_header.php")
		// Next time the user will be recognized using the $_SESSION['phRemember'] variable !
		setcookie('tempRemember' ,$_POST['rememberMe'], 0, "/");
		
		// Setting default preferences
		$_SESSION['USER_VIEW'] 	= 1 ;			// User view mode: see users (not administrators)
	}

/***********************************************************************************************/
/**********************				TESTING FUNCTIONS		 ***********************************/
/***********************************************************************************************/

	/**
	* Emulates data for custom authentication: "admin" or "user", where different users are recognized.
	* When the authentication is already been carried out by SSO, the session variavle "$userCode"
	* should already be in the session.
	*/
	function setSingleSignOn($user_id) {
	
		global $userCode ;
		if ($user_id > 0) 	$_SESSION[$userCode] = $user_id ;
		else 				unset($_SESSION[$userCode]) ;
	}

/***********************************************************************************************/
/**********************					DEPRECATED			************************************/
/***********************************************************************************************/

	/**
	* In current implementation, after authentication we forward action to the home page using:
	*		header("Location:home.php") ;		(see few lines above)
	* If in the future such solution should not work, we could restore the "old plain solution" (2006-2012).
	* This means substituting the above line with this one:
	*		include 'home.php' ;
	* which implies that we'll include the "session_header.php" page TWICE, leading to a PHP error.
	* In such scenario we should also uncomment the code below and copy-paste to the TOP of this page,
	* in order to set the necessary "minimal environment".
	*/

	/**
	* EMULATING SESSION HEADER
	* We can not include the "session_header.php" page, because it will be included by "home.php" (see end of this page)
	* All the other pages should include the "session_header.php" page, which takes care to start the session:
	* to avoid the risk to start the session twice in the same HTTP Request, we use the FIRST_LOGIN variable (see below).
	* REMARK: any modification to this code MUST BE copied also in the "session_header.php" page
	*/

	/*
	// 1. Starting session
	session_name('phractice');
	session_set_cookie_params(10*60);			// Making the cookie live for 10 minutes
	session_start();
	// 2. Setting names of common variables
	$logStatus 	= "status" ;
	$reference 	= "customer" ;
	$target 	= "target_customer" ;
	// 3. Defining the constant that will be checked in the "database_header.php" file
	// To reduce risk at minimum, we perform such check also in the "xxxDAO.php" pages
	define('INCLUDE_CHECK', true) ;
	// 4. Notifying to the included page that session has already been started
	*/
?>