<?php
	/**
	* This page represents the CARRIERS Database Access Object (DAO) of the entire system.
	* Every hard-coded detail about the carriers table must be specified here. In this way, if the
	* database is modified, it should be necessary to modify only this page (encapsulation concept).
	* This page contains following functions:
	*
	* SELECT QUERIES.
	* - countCarriers :
	* - getMaxCarrier :
	* - getCarrier :
	* - getCarriersList :
	* - getCarriersSelection :
	*
	* UPDATE QUERIES.
	* - updateCarrier :
	* - modifyCarrier :
	* - insertCarrier :
	* - deleteCarriers :
	*
	* UTILITIES.
	* - searchCarriers :
	* - getCarriersColumns :
	* - validateCarrier :
	* - isDelivered :
	* - getDropDownMenu :
	* - manageCarriersError :
	*
	* SHIPMENT DATES VALIDATION SETTING:
	*
	* There is a validation control checking the minimum in advance time for changing 
	* the carrier appointment date (planned date of the delivery), as explained in the Help section of the application. 
	* This validation criterion is parametrized by two variables: 
	*
	* $deliveryTime = 12 ;
	* $anticipation = 24 ; 
	*
	* The first parameter depicts the expected time of the delivery (0-24), the second one the minimum anticipation (hours) 
	* required before changing the delivery's  appointment date (see below).
	*/

/**********************************************************************************************/
/**********************				STATIC ACCESSORS		***********************************/
/**********************************************************************************************/

	// Static field: use for testing or debug
	$shipment_dao_debug = true ;

	/** Parameters.												*/
	$deliveryTime = 12 ;		// Day hour to take into consideration for the "time gap" (see validation)
	$anticipation = 24 ;		// Minimum anticipation time: 24 hours (carrier update)

	/** Setting general values.									*/
	$carriersType 		= array() ;
	$carriersWidth 		= getCarriersColumns() ;

	/** Retrieve the labels for the carriers headers			*/
	function getCarriersHeaders() {
		$columns = array(0=>"Nr.", 1=>"DDT", 3=>"Mittente", 4=>"Destinatario", 7=>"Pr.", 13=>"Appuntamento") ;
		return $columns ;
	}

	// TODO: refactor as above
	$carriersLongName 	= array(
		"Numero","Nr. DDT","Data DDT","Mittente","Destinatario","Indirizzo", "Citt&agrave","Provincia",
		"Nr. Ordine","Data Ordine","Nr. Colli","Peso","Data Filiale","Data Appuntamento",
		"Data Consegna", "Note"
	) ;

/**********************************************************************************************/
/**********************			SELECT QUERY METHODS		***********************************/
/**********************************************************************************************/

	/** Retrieve the number of records for the carriers table			*/
	function countCarriers($where) {

		global $result ;

		$query = "SELECT count(*) FROM shipments" ;
		if ($where != "") $query .= " WHERE " . $where ;
		// Keep for testing or debug
		//print "DAO query: $query<br/>" ;
		$result = mysql_query($query) or manageCarriersError() ;
		$riga 	= mysql_fetch_row($result) ;
		return $riga[0] ;
	}

	/** Retrieve the carriers maximum code number.						*/
	function getMaxCarrier() {

		global $result ;

		$query  = "SELECT MAX(shipment_nr) FROM shipments" ;
		$result = mysql_query($query) or manageCarriersError() ;
		$riga 	= mysql_fetch_row($result) ;
		return $riga[0] ;
	}

	/** Retrieve the carrier data sheet.								*/
	function getCarrier($code) {

		global $result ;

		$query = "SELECT * FROM shipments WHERE shipment_nr = " . $code;
		// Keep for testing or debug
		//print "DAO query: $query<br/>" ;
		$result = mysql_query($query) or manageCarriersError() ;
		return $result ;
	}

	/** Retrieve the carriers main data.								*/
	function getCarriersList($where, $limit, $start) {

		global $result ;

		$query  = "SELECT * FROM shipments" ;
		if ($where != "") $query .= " WHERE " . $where ;
		$query .= " ORDER BY planned_date DESC " ;
		if ($start >= 0) $query .= "LIMIT " . $limit . " OFFSET " . $start ;
		// Keep for testing or debug
		//print "DAO query: $query<br/>" ;
		$result = mysql_query($query) or manageCarriersError() ;
		return $result ;
	}

	/** Retrieve the carriers identified by the input array (MULTIPLE DELETE)			*/
	function getCarriersSelection($selection) {

		global $result ;

		$counter = 0 ;
		$query  = "SELECT * FROM shipments WHERE (" ;
		$howMany = count($selection) ;
		if ($howMany >= 1) foreach ($selection as $index) {
		  $counter++ ;
		  $query .= "shipment_nr = '$index'" ;
		  if ($counter < $howMany) $query .= " OR " ;
		  elseif ($counter == $howMany) $query .= " ) ORDER BY shipment_nr" ;
		}
		// Keep for testing or debug
		//print "DAO query: $query<br/>" ;
		$result = mysql_query($query) or manageCarriersError() ;
		return $result ;
	}

/**********************************************************************************************/
/**********************			EXECUTE UPDATE METHODS		***********************************/
/**********************************************************************************************/

	/**
	* Update the carrier's data in the database.
	* This is the UPDATE function allowed to administrators.
	*/
	function updateCarrier($code, $values) {

		global $result ;

		$query  = "UPDATE shipments SET shipment_nr = '$values[0]', document_nr = '$values[1]', document_date = '$values[2]', sender = '$values[3]', " ;
		$query .= "recipient = '$values[4]', address = '$values[5]', town = '$values[6]', province = '$values[7]', " ;
		$query .= "order_nr = '$values[8]', order_date = '$values[9]', boxes = '$values[10]', weight = '$values[11]', " ;
		$query .= "store_date = '$values[12]', planned_date = '$values[13]', delivery_date = '$values[14]', notes = '$values[15]' " ;
		$query .= "WHERE shipment_nr = " . $code;
		// Keep for testing or debug
		//print "DAO query: $query<br/>" ;
		$result = mysql_query($query) or manageCarriersError() ;
		return $result ;
	}

	/** Modify the carrier's data in the database.
	*  This is the UPDATE function allowed to common users.
	*/
	function modifyCarrier($code, $values) {

		global $result ;

		$query  = "UPDATE shipments SET planned_date = '$values[13]', notes = '$values[15]' " ;
		$query .= "WHERE shipment_nr = " . $code;
		// Keep for testing or debug
		//print "DAO query: $query<br/>" ;
		$result = mysql_query($query) or manageCarriersError() ;
		return $result ;
	}

	/** Insert the carrier's data in the database.						*/
	function insertCarrier($values) {

		global $result ;

		$query  = "INSERT INTO shipments VALUES('$values[0]','$values[1]','$values[2]','$values[3]','$values[4]', '$values[5]', ";
		$query .= "'$values[6]','$values[7]','$values[8]','$values[9]','$values[10]', '$values[11]', '$values[12]', ";
		$query .= "'$values[13]','$values[14]','$values[15]')" ;
		// Keep for testing or debug
		//print "DAO query: $query<br/>" ;
		$result = mysql_query($query) or manageCarriersError() ;
		return $result ;
	}

	/** Delete the carrier's from the database.							*/
	function deleteCarriers($codes) {

		$index = 0 ;
		$number = count($codes) ;
		$query  = "DELETE FROM shipments WHERE (" ;
		foreach ($codes as $value) {
		  $index++ ;
		  $query .= "shipment_nr = '$value' " ;
		  if ($index < $number) $query .= "OR " ;
		}
		$query .= ")" ;
		// Keep for testing or debug
		//print "DAO query: $query<br/>" ;
		$rows = mysql_query($query) or manageCarriersError() ;
		return $rows ;
	}

/**********************************************************************************************/
/***************************			UTILITIES			***********************************/
/**********************************************************************************************/

	/** Set the search parameters.									*/
	function searchCarriers() {

		global $target ;

		$clause = "" ;
		$varName = "searchQuery" ;

		// Each time we get parameters form the search page we set the new $searchQuery variable
		if ( (isset($_POST['who'])) && (isset($_POST['when'])) && (isset($_POST['what'])) ) {
			$who = $_POST['who'] ;
			$when = $_POST['when'] ;
			$what = $_POST['what'] ;
			if ($who != "") $who = findCustomer($who) ;
			if ($when != "") $when = setDate($when) ;
			if ($who != "") $condition[0]  = "(sender = '$who' OR recipient = '$who')" ;
			if ($when != "") $condition[1] = "(document_date = '$when' OR order_date = '$when' OR store_date ='$when' OR planned_date = '$when' OR delivery_date = '$when')" ;
			if ($what != "") $condition[2] = "(shipment_nr = '$what' OR document_nr = '$what' OR order_nr = '$what')" ;
			for ($n = 0; $n < 3; $n++) {
				if (isset($condition[$n])) {
					$clause .=  $condition[$n] ;
					if ( (isset($condition[$n+1])) || (isset($condition[$n+2])) ) $clause .= " AND " ;
				}
			}
			$_SESSION[$varName] = $clause ;
			return $clause ;
		}
		// If we don't come from the search page, we check the "page" parameter
		if (isset($_GET['page'])) {
			if (isset($_SESSION[$varName])) $clause = $_SESSION[$varName] ;
		} else {
			$clause = "" ;
			if (isset($_SESSION[$varName])) unset($_SESSION[$varName]) ;
		}
		return $clause ;
	}

	/** Return an array containing the fields length.						*/
	function getCarriersColumns() {

		global $result,$carriersType ;

		$index = 0 ;
		$query = "SELECT * FROM shipments where shipment_nr > 0";
		$result = mysql_query($query) or manageCarriersError() ;
		while ($index < mysql_num_fields($result)) {
		  $meta = mysql_fetch_field($result);
		  if (!$meta) { echo "Nessuna informazione disponibile<br>\n"; }
		  $size[$index] = $meta->max_length ;
		  $carriersType[$index] = $meta->type ;
		  $index++;
		}
		// Forcing the value for the foreign keys
		$size[3] = 20 ;
		$size[4] = 20 ;

		return $size ;
	}

	/**
	* Check if carrier modifications are allowed. Parameters of the carrier can be changed only if:
	* - appointment date (i.e. planned date) is more than 24 hours in the future: see "$anticipation" global variable
	* - appointment date (i.e. planned date) is before 12 o'clock of the day before the planned date: see "$deliveryTime" global variable
	* RESULTING CRITERIA: before 12 A.M. it's possible to set tomorrow as planned data, after 12 A.M. it's necessary to set the day
	* after tomorrow as planned date.
	*/
	function validateCarrier($values) {

		global $anticipation, $deliveryTime ;

		// Validate conditions
		$now 			= time() ;
		$minDelay 		= $anticipation*3600 ;
		$input[0] 		= formatDate($values[13]) ;
		$delivery 		= getTimestamp($input[0]) + $deliveryTime*3600 ;
		$condition[0]	= ( ($delivery - $now) >= $minDelay ) ;
		// Keep for testing or debug
		// print "Hours: ".(($delivery - $now)/3600)."<br/>" ;
		return $condition ;
	}

	/** Tells if the carrier has been already delivered.						*/
	function isDelivered($dateValue) {

		$result = 0 ;
		$now = time() ;
		$ts = getTimestamp($dateValue) ;
		$result = ( ($ts >= $now) || ($ts ==0) ) ;
		//print ("Pendente: " . $result . "x") ;
		return $result ;
	}

	/** Print the customer drop-down menu.							*/
	function lookupCustomers($value, $customers) {

		$result = "" ;
		foreach($customers as $index => $name) {
			$menuEntry = $name." [". $index."]" ;
			if ($index != $value) 	$result .= "<option value='$index'>".$menuEntry."</option>" ;
			else 					$result .= "<option value='$index' selected>".$menuEntry."</option>" ;
		}
		return $result ;
	}

	/** Manages SQL errors.									*/
	function manageCarriersError() {

		global $shipment_dao_debug ;

		echo "Holas !" ;
		if ($shipment_dao_debug) echo mysql_error();
		//die("Query fallita") ;
	}
?>