<?php
	/** 
	* This is the page (to be included in other page) that takes care of the session and authentication.
	* Moreover this page manages the paging navigation when the user consults a long list of records.
	*
	* IMPORTANT: this page MUST BE include by all not-public pages to avoid access to users not logged in.
	* (see the "checkLogin()" funtion below)
	*/

	/** 
	* MINIMAL ENVIRONMENT: if any other page should initialize session and environment without 
	* including this session_header, following code-block should be copy-pasted into that page.
	* This could be the case of the "authenticate.php" if the "header("Location:home.php")" 
	* code does not work and it's necessary to replace it with "include 'home.php'".
	* In such scenario, this code-block should be surrounded by an IF clause, for example:
	*	if ( !isset($firstLogin)	)	{ ...  }		
	* or 		
	*	if ( !defined('FIRST_LOGIN')) 	{ ...  }
	*/
	// 1. Starting session
	session_name('phractice') ;
	session_set_cookie_params(24*60*60) ;		// Making the cookie live for 24 hours
	session_start() ;
	// 2. Setting names of GLOBAL KEYWORDS (used to name session variables)
	// REMARK: remember to define these in the "global" section of each function using them!
	$logStatus 	= "status" ;				// User role: user or administrator
	$reference 	= "customerID" ;			// Used to identify the user (should be a primary key or unique field)
	$target 	= "target_customer" ;		// Target users: see the "carriers_list.php" page
	$phRemember	= "phRemember" ;			// Name of the cookie for the "rememberMe" function
	$loggedName	= "loggedName" ;
	// 3. Defining the constant that will be checked in the "database_header.php" file
	// To reduce risk at minimum, we perform such check also in the "xxxDAO.php" pages
	define('INCLUDE_CHECK', true) ;
	// 4. Setting debug mode (see Apache's error.log file to read log messages)
	$debug 			= true ;
	$leading_name 	= "PHRACTICE --> " ;
	
	// PAGING PARAMETERS
	$offset 		= 0 ; 	 		// Index of the 1st record to be retrieved
	$records 		= 0 ;  			// Total number of records found
	$maxLimit 		= 10 ;			// Maximum number of record in one page (SELECT... LIMIT x OFFSET f)    
	$lastPage 		= 0 ;			// Total number of pages to be shown
	$pageNumber 	= 0 ;			// Current page to be shown (from the request GET)
	$pageCounter 	= "counter" ;	// Used for statistics about the user
	
/********************************************************************************************/
/**********************			REMEMBER ME MANAGEMENT		*********************************/
/********************************************************************************************/
	
	/* 
	* The "tempRemember" cookie is used only during the login session, since this cookie expires when the user quits the browser
	* The codeblock activates only when the user closes and reopens the browser within the session's expire time: in such
	* case the session variables will be still there, i.e: $_SESSION['id'] and $_SESSION['phRemember'] will hold the previous values.
	* Hence the real "trigger condition" of the IF clause is:
	*
	* $_COOKIE['tempRemember'] SET 		AND	 $_SESSION['phRemember'] = '0' 	--> 	User logged in CURRENT session WITHOUT the phRemember option
	* $_COOKIE['tempRemember'] NOT SET 	AND	 $_SESSION['phRemember'] = '0' 	--> 	User logged in PREVIOUS session WITHOUT the phRemember option
	* $_COOKIE['tempRemember'] SET 		AND	 $_SESSION['phRemember'] = '1' 	--> 	User logged in CURRENT session WITH the phRemember option
	* $_COOKIE['tempRemember'] NOT SET 	AND	 $_SESSION['phRemember'] = '1' 	--> 	User logged in PREVIOUS session WITH the phRemember option
	*
	* In this way we recognize the 2nd situation, and we must destroy the session! 
	* Remark: destroy the session means starting it again, with an updated expire date, but probably with the same SESSION ID !
	*/ 
	if (isset($_SESSION['customerID']) && $_SESSION['customerID'] && !isset($_COOKIE['tempRemember']) && !$_SESSION['phRemember']) {
		// The user is logged in, but doesn't have the "tempRemember" cookie (browser restart)
		// and has not checked the rememberMe checkbox
		
		$_SESSION = array();
		session_destroy();
		if ($debug) error_log($leading_name."Session and cookie condition --> session destroyed") ;
		
		// TODO: implementare registrazione utenti:
		// - Riprendere a copiare dalla demo.php, alla riga 103 (REGISTRATION FORM)		
		// - Eventualmente copiare anche parte del metodo logOff.
	}
      
/********************************************************************************************/
/**********************		SESSION MANAGEMENT		*****************************************/
/********************************************************************************************/

	/** Retrieve the authentication parameters from the session.							*/
	function setSession() {
	
		global $pageCounter ;
		// Providing statistics for this user 
		if (isset($_SESSION[$pageCounter])) $_SESSION[$pageCounter]++ ;
		else 								$_SESSION[$pageCounter] = 0 ;
	}
  
	/** Check the user authentication status (as stored in the session).					*/
	function checkLogin() {
	
		global $logStatus ;
		if (isset($_SESSION[$logStatus])) if ($_SESSION[$logStatus] >= 0) return TRUE ;
		include "../home/guest.php" ;
		die() ;   
	}
  
	/** Logs out the user and destroy the session variables.						*/
	function logout() {
	
		global $target, $reference, $loggedName, $logStatus ;
		$result = FALSE ;
		if (isset($_SESSION[$target])) 		unset($_SESSION[$target]) ;
		if (isset($_SESSION[$reference])) 	unset($_SESSION[$reference]) ;
		if (isset($_SESSION[$loggedName])) 	unset($_SESSION[$loggedName]) ;
		if (isset($_SESSION[$logStatus])) {
		  unset($_SESSION[$logStatus]) ;
		  $result = TRUE ;
		}
		return $result ;
		
		// An harder version of this logout form could be
		//$_SESSION = array();
		//session_destroy();
	}
  
/****************************************************************************************/
/**********************			PAGING 			*****************************************/
/****************************************************************************************/

	/** Set the paging parameters.										*/
	function formatPage($mode, $where, $table) {
    
		global $offset, $maxLimit, $pageNumber, $lastPage, $records ;

		// Initializing the page parameters (stored in the session)
		if (!isset($_SESSION['lastPage'])) {
			$_SESSION['records'] 	= $records ;
			$_SESSION['lastPage'] 	= $lastPage ;
		} else {
			$records	= $_SESSION['records'] ;
			$lastPage 	= $_SESSION['lastPage'] ;
		}
        
		// Counting all records in order to set the "lastPage" value.
		// If "page" exists --> we go to the specified page
		if (isset($_GET['page'])) $pageNumber = $_GET['page'] ;
		// If "page" does not exists --> we refresh the recordset
		else { 
			$pageNumber = 1 ;
			if 		($table == "users") 	$records = countCustomers($mode, $where) ;
			elseif 	($table == "carriers") 	$records = countCarriers($where) ;
			$lastPage = ceil($records/$maxLimit) ;
			$_SESSION['records'] 	= $records ;
			$_SESSION['lastPage'] 	= $lastPage ;
		}
    
		// Now calcolating the offset for these records
		$offset = ($pageNumber - 1)*$maxLimit ;
	}
	
/***********************************************************************************************/ 
/**********************				DEBUG SECTION			************************************/
/***********************************************************************************************/

	// Showing debug information (see Apache's error.log file to read log messages)
	if ($debug) {
		if (isset($_COOKIE['tempRemember'])) 	error_log($leading_name."[tempRemember] (Cookie) = ".$_COOKIE['tempRemember']	) ;
		else									error_log($leading_name."[tempRemember] (Cookie) = null"							) ;
		if (isset($_SESSION['phRemember'])) 	error_log($leading_name."[phRemember] (Session)  = ".$_SESSION['phRemember']		) ;
		else									error_log($leading_name."[phRemember] (Session)  = null"							) ;
	}
 
/***********************************************************************************************/ 
/**********************					PHP BODY			************************************/
/***********************************************************************************************/

	// We must start the session in every page of the system!
	setSession() ;
	if (!defined('FIRST_LOGIN')) checkLogin() ;

?> 