<?php	  
	/** 
	* Testing features of the actual DAO approach (Object Oriented).
	* Showing how to INSERT data (SAVE operation).
	*/

	// Defining base URL
	$root = "../../" ;

	include $root.'include/session_header.php' ; 		// Including pages that take care of the session and database  
	include $root.'include/database_header.php' ;		// Managing database connections  
	include $root.'include/display_header.php' ;		// Defining layout, images and loading the left menu    
            
	include $root.'classes/UserVO.php' ;				// Including the Value Object user class
	include $root.'classes/UserDAO.php' ;				// Including the actual user DAO (OOP)
?>

<script>
// Appending the users CSS at run-time
linkElement 		= document.createElement("link") ;
linkElement.rel 	= "stylesheet" ;
linkElement.href 	= "<?php echo $root ; ?>css/tutorial.css" ; 
document.head.appendChild(linkElement) ;
</script>

<div class="content_01">

<h3>SQL INSERT operation with the DAO approach</h3>

<p>
This page shows an example of the <strong>INSERT</strong> operation with the DAO approach, using the <code>save()</code>
DAO function (which manages both the SQL INSERT and UPDATE operations).
<br/><br/>
This example retrieves an existing user, clones it and modifies just a couple of user's data, in order to create a new
<code>userVO</code> to be inserted in the database. Notice that we must set the user's ID to 0 (zero) otherwise
the <code>save()</code> function would try to update an existing user (see DAO implementation).
<br/><br/>
<strong>Remark</strong>: each time this page is loaded a new user is inserted in the database!
<br/><br/>
For an example of the <code>UPDATE</code> operation see next page.
</p>


<br/>

<p><em>Sample code:</em></p>

<div class="dao-code">
<pre><code>
// 1. Creating the DAO instance using the $connection parameter 
// (defined by the "database_header.php" page)
$dao 		= new UserDAO($connection) ;
// 2. Retrieving an existing user and using it to clone a new user
$userVO 	= $dao->get(1) ;
$array 		= $userVO->getAllData() ;
$array[0] 	= 0 ;
$array[1] 	= 'John' ;
$array[2] 	= 'Smith' ;
$newUser	= new userVO($array) ;
echo '&lt;strong&gt;Cloned used:&lt;/strong&gt; ' ;
foreach ($array as $value) echo $value.' - ' ;
// 3. Saving the new user in the database
$result = $dao->save($newUser) ;
// Remark: this does not work because "insert()" is private (as designed)
// $dao->insert($newUser) ;
</code></pre>
</div>

<br/>

<p><em>Input data:</em></p>

<div class="dao-code">
<?php
	// 1. Creating the DAO instance using the $connection parameter (defined by the "database_header.php" page)
	$dao 		= new UserDAO($connection) ;
	// 2. Retrieving an existing user and using it to clone a new user
	$userVO 	= $dao->get(1) ;
	$array 		= $userVO->getAllData() ;
	$array[0] 	= 0 ;
	$array[1] 	= 'John' ;
	$array[2] 	= 'Smith' ;
	$newUser	= new userVO($array) ;
	echo '<strong>Cloned used:</strong> ' ;
	foreach ($array as $value) echo $value.' - ' ;
	// 3. Saving the new user in the database
	$result = $dao->save($newUser) ;
	// Remark: this does not work because "insert()" is private (as designed)
	// $dao->insert($newUser) ;
?> 
</div>

<br/>

<p><em>Result:</em></p>

<div class="dao-code">
<?php
	echo '<strong>User ID</strong>: '.$result ;
	if ($result > 0) 	$param = "lastID=$result" ;
	else				$param = "lastID=0" ;
?>
</div>

<br/><br/>

<nav class="dao-page">
<span><a href="01-test-dao.php"								title="Retrieving user data in the DAO approach">Previous</a></span>
<span><a href="03-test-update.php?<?php echo $param?>"		title="Testing the UPDATE operation">Next</a></span>
</nav>

</div>

<br/><br/><br/>

<?php include $root.'include/display_footer.php' ;  ?>