<?php	  
	/** 
	* Testing features of the actual DAO approach (Object Oriented).
	* Showing how to UPDATE data (SAVE operation).
	*/

	// Defining base URL
	$root = "../../" ;
	
	include $root.'include/session_header.php' ; 		// Including pages that take care of the session and database  
	include $root.'include/database_header.php' ;		// Managing database connections  
	include $root.'include/display_header.php' ;		// Defining layout, images and loading the left menu    
            
	include $root.'classes/UserVO.php' ;				// Including the Value Object user class
	include $root.'classes/UserDAO.php' ;				// Including the actual user DAO (OOP)
?>

<script>
// Appending the users CSS at run-time
linkElement 		= document.createElement("link") ;
linkElement.rel 	= "stylesheet" ;
linkElement.href 	= "<?php echo $root ; ?>css/tutorial.css" ; 
document.head.appendChild(linkElement) ;
</script>

<div class="content_01">

<h3>SQL UPDATE operation with the DAO approach</h3>

<p>
This page shows an example of the <strong>UPDATE</strong> operation with the DAO approach, using the <code>save()</code>
DAO function (which manages both the SQL INSERT and UPDATE operations).
<br/><br/>
We retrieve the last inserted user from previous page (the user ID is passed simply as a HTTP GET request parameter),
then we modify the related <code>userVO</code> and save it into the database. We must make sure the user's ID is different from 
zero, otherwise the <code>save()</code> function would try to insert a new user (see DAO implementation).
<br/><br/>
The modified fiels are: <em>name</em>, <em>surname</em> and <em>ZIP</em> code (this is changed with a randon criterion to allow multiple updates).
<br/><br/>
<strong>Remark</strong>: each time this page is loaded the last inserted user is modified!
<br/><br/>
For an example of the <code>INSERT</code> operation see previous page.
</p>

<br/>

<p><em>Sample code:</em></p>

<div class="dao-code">
<pre><code>
// 1. Creating the DAO instance using the $connection parameter
// (defined by the "database_header.php" page)
$dao 		= new UserDAO($connection) ;
// 2. Getting the last user ID
// (as set by previous page: see "02-test-insert.php")
if ( isset($_GET['lastID']) )   $lastID	= $_GET['lastID'] ;
else                            $lastID	= 0 ;
// 3. Retrieving the user and showing data
$userVO 	= $dao->get($lastID) ;
$array 		= $userVO->getAllData() ;
echo '&lt;strong&gt;Old data:&lt;/strong&gt; ' ;
foreach ($array as $value) echo $value.' - ' ;
// 4. Creating a new userVO with the modified data
$array[1] 	= 'Scott' ;
$array[2] 	= 'Tiger' ;
$array[7]	= rand(10000,50000) ;
$newUser	= new userVO($array) ;
echo '&lt;br/&gt;&lt;br/&gt;' ;
echo '&lt;strong&gt;New data:&lt;/strong&gt; ' ;
foreach ($array as $value) echo $value.' - ' ;
// 5. Saving the new user in the database
$result = $dao->save($newUser) ;
// Remark: this does not work because "update()" is private (as designed)
// $dao->update($newUser) ;
</code></pre>
</div>

<br/>

<p><em>User data:</em></p>

<div class="dao-code">
<?php
	// 1. Creating the DAO instance using the $connection parameter (defined by the "database_header.php" page)
	$dao 		= new UserDAO($connection) ;
	// 2. Getting the last user ID (as set by previous page: see "02-test-insert.php")
	if ( isset($_GET['lastID']) )	$lastID	= $_GET['lastID'] ;
	else							$lastID	= 0 ;
	// 3. Retrieving the user and showing data
	$userVO 	= $dao->get($lastID) ;
	$array 		= $userVO->getAllData() ;
	echo '<strong>Old data:</strong> ' ;
	foreach ($array as $value) echo $value.' - ' ;
	
	// 4. Creating a new userVO with the modified data
	$array[1] 	= 'Scott' ;
	$array[2] 	= 'Tiger' ;
	$array[7]	= rand(10000,50000) ;
	$newUser	= new userVO($array) ;
	echo '<br/><br/>' ;
	echo '<strong>New data:</strong> ' ;
	foreach ($array as $value) echo $value.' - ' ;
	
	// 5. Saving the new user in the database
	$result = $dao->save($newUser) ;
	// Remark: this does not work because "update()" is private (as designed)
	// $dao->update($newUser) ;
?> 
</div>

<br/>

<p><em>Result:</em></p>

<div class="dao-code">
<?php
	echo '<strong>Updated user:</strong>: '.$result ;
	if ($result > 0) 	$param = "lastID=$result" ;
	else				$param = "lastID=0" ;
?>
</div>

<br/><br/>

<nav class="dao-page">
<span><a href="02-test-insert.php" 							title="Testing the INSERT operation">Previous</a></span>
<span><a href="04-test-delete.php?<?php echo $param?>"		title="Testing the DELETE operation">Next</a></span>
</nav>

</div>

<br/><br/><br/>

<?php include $root.'include/display_footer.php' ;  ?>