<?php	  
	/** 
	* Testing features of the actual DAO approach (Object Oriented).
	* Showing how to DELETE data.
	*/

	// Defining base URL
	$root = "../../" ;
	
	include $root.'include/session_header.php' ; 		// Including pages that take care of the session and database  
	include $root.'include/database_header.php' ;		// Managing database connections  
	include $root.'include/display_header.php' ;		// Defining layout, images and loading the left menu    
            
	include $root.'classes/UserVO.php' ;				// Including the Value Object user class
	include $root.'classes/UserDAO.php' ;				// Including the actual user DAO (OOP)
?>

<script>
// Appending the users CSS at run-time
linkElement 		= document.createElement("link") ;
linkElement.rel 	= "stylesheet" ;
linkElement.href 	= "<?php echo $root ; ?>css/tutorial.css" ; 
document.head.appendChild(linkElement) ;
</script>

<div class="content_01">

<h3>SQL DELETE operation with the DAO approach</h3>

<p>
This page shows an example of the <strong>DELETE</strong> operation with the DAO approach, using the <code>delete()</code>
DAO public function.
<br/><br/>
We retrieve the last updated user from previous page (the user ID is passed simply as a HTTP GET request parameter)
and we delete that user.
<br/><br/>
<strong>Remark</strong>: each time this page is loaded the last modified user is deleted!
<br/><br/>
For an example of the <code>INSERT</code> and <code>UPDATE </code>operations see previous pages.
</p>

<br/>

<p><em>Sample code:</em></p>

<div class="dao-code">
<pre><code>
// 1. Creating the DAO instance using the $connection parameter
// (defined by the "database_header.php" page)
$dao 		= new UserDAO($connection) ;
// 2. Getting the last user ID 
// (as set by previous page: see "03-test-update.php")
if ( isset($_GET['lastID']) )   $lastID	= $_GET['lastID'] ;
else                            $lastID	= 0 ;
// 3. Retrieving the user and showing data
$userVO 	= $dao->get($lastID) ;
$array 		= $userVO->getAllData() ;
echo '&lt;strong&gt;User data:&lt;/strong&gt; ' ;
if ($array) foreach ($array as $value) 	echo $value.' - ' ;
else { 
	echo "User $lastID not found in the database" ;
	$lastID = 0 ;
}
// 4. Deleting the user from the database (if found)
if ($lastID > 0) 	$result = $dao->delete($lastID) ;
else				$result = "None" ;
</code></pre>
</div>

<br/>

<p><em>Input data:</em></p>

<div class="dao-code">
<?php
	// 1. Creating the DAO instance using the $connection parameter (defined by the "database_header.php" page)
	$dao 		= new UserDAO($connection) ;
	// 2. Getting the last user ID (as set by previous page: see "03-test-update.php")
	if ( isset($_GET['lastID']) )	$lastID	= $_GET['lastID'] ;
	else							$lastID	= 0 ;
	// 3. Retrieving the user and showing data
	$userVO 	= $dao->get($lastID) ;
	$array 		= $userVO->getAllData() ;
	echo '<strong>User data:</strong> ' ;
	if ($array) foreach ($array as $value) 	echo $value.' - ' ;
	else { 
		echo "User $lastID not found in the database" ;
		$lastID = 0 ;
	}
	// 4. Deleting the user from the database (if found)
	if ($lastID > 0) 	$result = $dao->delete($lastID) ;
	else				$result = "None" ;
?> 
</div>

<br/>

<p><em>Result:</em></p>

<div class="dao-code">
<?php
	echo '<strong>Deleted user</strong>: '.$result ;
	// If we go back to previous page we'll try to modify the previous user
	// (the one that should be before the just deleted user)
	$param = "lastID=".($_GET['lastID'] - 1)  ;
?>
</div>

<br/><br/>

<nav class="dao-page">
<span><a href="03-test-update.php?<?php echo $param?>" 		title="Testing the UPDATE operation">Previous</a></span>
</nav>

</div>

<br/><br/><br/>

<?php include $root.'include/display_footer.php' ;  ?>