<?php	
	include_once 'test_header.php' ;	
	include_once 'my_class.php' ;
	// Defining formatting helper variable
	$holds = ' <span>returns</span> ' ;
?>
	
<h3>Sharing objects using the HTTP session (part 2)</h3>
<p>	
This page shows that even sharing the same object within the same page the static field is LOST!<br/>
This does not depend by the serialization/deserialization process, because in the previous page ("<code>05-sharing_objects_2.php</code>")<br/>
we saw that such process does not change the object within the same page.
<br/><br/>
This proves that when an object gets loaded from the HTTP session a new class is created, i.e. a new "class loader" is used each
time we refresh this page.<br/>
Hence only ordinary class fields (not static) can be shared using the HTTP session (even in the same page).
<br/><br/>
<strong>Press F5</strong> to set/unset the object from the HTTP session.
</p>

<pre>

<?php

/**
* Another simple test class
*/
class MyClass {

    static 	private $foo_static = "default" ;
    private 		$foo 		= "default" ;

    static function getString_static() {
        return self::$foo_static ;
    }

    static function setString_static($str) {
        self::$foo_static = $str ;
    }

    function setString($str) {
        $this->foo = $str ;
    }

    function getString() {
        return $this->foo ;
    }

} // End of class

// MAIN CODE

// If the my_Obj object is NOT in the HTTP session we create it
if (!isset($_SESSION['my_Obj'])) {
	
	// Creating an instace of the inner helper class
    $myObj = new MyClass() ;
	// Uncomment this to verify that things does not change using an "external" definition of the class
    //$myObj = new MyClassExternal() ;
	
    $myObj->setString_static("A static value") ;
    $myObj->setString("A normal value (not static)") ;

	echo "Missing object reference in the HTTP session...\n\n" ;
    echo "Printing object content (just created): \n\n" 	;
    echo 'Normal Field: ' . $myObj->getString() . "\n" ;
    echo 'Static Field: ' . $myObj->getString_static() ;

    echo "\t\n\nNow serializing and unserializing the object... " ;
    $myObj = unserialize(serialize($myObj)) ;

    echo "and printing again the object content (to verify nothing changed):\n\n" ;
    echo 'Normal Field: ' . $myObj->getString() . "\n" ;
    echo 'Static Field: ' . $myObj->getString_static() . "\n\n" ;

    //Store object in session
	echo "Finally we store the serialized object in the HTTP session: " ;
	echo "this will allow us to find it when the page is reloaded." ;
    $_SESSION['my_Obj'] = serialize($myObj) ;

//if my_Obj is found in the HTTP session we show object's content
} else {

	echo "Found object reference in the HTTP session!\n\n" ;
	echo "Deserializating the object...\n\n" ;
    $myObj_loaded = unserialize($_SESSION['my_Obj']) ;

    echo "Now printing content after serialization, session storage, unserialization and page reload:\n\n" ;
    echo 'Normal Field: ' . $myObj_loaded->getString() . "\n" ;
    echo 'Static Field: ' . $myObj_loaded->getString_static() . "\n\n" ;
	
	echo "Result: even sharing the same object within the same page the static field is LOST!\n\n" ;
	
	echo "Finally we remove the object from the session to allow test repetion...\n\n" ;
    unset($_SESSION['my_Obj']) ;
	echo "Session cleaned!!!"  ;
}
?>
</pre>


<?php	include_once 'test_footer.php' ;	?>