<?php
/**
* Simple class used to show some basic PHP Object Oriented features:
* 
* 1. We use $OBJECT->METHOD() when referring to objects, and CLASS::METHOD() when referring to classes.
*	 For this reason we use $THIS->FIELD to refer class's instance fields, and SELF::FIELD to refer
*	 to class's static fields. This explains why the keyword "this" requires the dollar sign ($).
*
* 2. The STATIC keyword is not actually common to instances, because every PHP page has is 
* 	 own "class loader" --> static fields are common only to objects within the same page!
*	 See the STATIC_FIELD_1.PHP and STATIC_FIELD_2.PHP, where the same static field has
*	 different values, because we have "one different class for every page".
*
* 3. Within the same page, static fields behave as in standard OOP: see STATIC_FIELD_1.PHP page,
*	 where two different objects share the same static field value.
*/
class TestObject {

	/** Ordinary class field 						*/
    public 			 		$my_field 			= 'empty' ;
	/** Static class field 							*/
    public 		static 		$public_static 		= 5 ;
	/** Static class field 							*/
    private 	static 		$private_static		= 10 ;
	/** Static class field 							*/
    protected 	static 		$protected_static	= 20 ;
	
	/** 
	* Standard constructor, compatible with old PHP versions: in new PHP versions, after
	* introduction of namespace (similar to Java packages), we can name the constructor
	* like the class (as in Java).
	*/
	function __construct($value) {	
	
		$this->my_field = $value ;
	}
	
/********************************************************************************************
/****************************			CLASS FIELDS				*************************
/********************************************************************************************

    /** Getter method (for the static value).												*/
    public function getFieldValue() 			{		return $this->my_field ;		    }
	
	/** Setter method (for the static value).												*/
    public function setFieldValue($value)		{		$this->my_field = $value;			}

/********************************************************************************************
/****************************			STATIC FIELDS				*************************
/********************************************************************************************
	
	/** Mutator method.																		*/
    public function incrementStatic() 			{		self::$public_static++ ;		    }

    /** Getter method (for the static value).												*/
    public function getStaticValue() 			{		return self::$public_static ;	    }
	
	/** Setter method (for the static value).												*/
    public function setStaticValue($value)		{		self::$public_static = $value;		}
	
/********************************************************************************************
/****************************		TESTING STATIC VARIABLES		*************************
/********************************************************************************************
	
	/** Mutator method.																		*/
    public static function staticTest() {		
		static $inner = 0 ;
		$inner++ ;
		return $inner ;
	}
	
	/** Mutator method.																		*/
    public static function nonStaticTest() {		
		$inner = 0 ;
		$inner++ ;
		return $inner ;
	}
	
} // End of class
?>