<?php	
	$root = "../../ " ;
	// Including libraries
	include_once 	'test_header.php' ;	
?>

<h3>Searching the file system</h3>

<p style="width:70%">
This page implements a <code>findFiles()</code> function using the <strong>glob()</strong> PHP function.
<br/><br/>
The <code>findFiles()</code> function looks file in the current directory, using a CASE-SENSITIVE search, more advanced that the
basic <code>scandir</code> function (of the Directory extension). 
This is achieved using the <code>glob()</code> function of the Filesystem extension.
<br/><br/>
Note: this page contains also a <code>printFiles()</code> function offering two usages:<br/>
- If invoked with 1 parameter (an array) the function just prints the array elements.<br/>
- If invoked with 2 parameters (an array and a dummy parameter) the function prints the absolute path of each array's element.<br/>
 (the dummy parameter can hold any value)<br/>
</p>

<?php 
	// 1. Invoking findFiles() with 1 parameter (in current directory)
	echo '<strong>Searching files using search string <code>*.php</code></strong> (in current directory)<br/><br/>' ;
	echo 'Command:<br/><br/>' ;
	echo '<code>printFiles( findFiles("*.php") ) ;</code><br/><br/>' ;
	echo 'Result:<br/><br/>' ;	
	printFiles( findFiles("*.php") ) ;
	echo '<br/><hr/>' ;

	// 2. Invoking findFiles() with 1 parameter (relative path)
	echo '<strong>Searching files using search string <code>../../images/*.png</code></strong> (relative path)<br/><br/>' ;
	echo 'Command:<br/><br/>' ;
	echo '<code>printFiles( findFiles("../../images/*.png") ) ;</code><br/><br/>' ;
	echo 'Result:<br/><br/>' ;	
	printFiles( findFiles("../../images/*.png") ) ;
	echo '<br/><hr/>' ;

	// 3. Invoking findFiles() with 2 parameters (using the GLOB_BRACE option)
	echo '<strong>Searching files using the <code>GLOB_BRACE</code> option</strong> (2 different file extensions)<br/>' ;
	echo '<p>The <code>GLOB_BRACE</code> option allows to search using a set of file extensions (and not just one as above)</p>' ;
	echo 'Command:<br/><br/>' ;
	echo '<code>printFiles( findFiles("*.{foo,txt}", GLOB_BRACE), 1) ;</code><br/><br/>' ;
	echo 'Result:<br/><br/>' ;	
	printFiles( findFiles("*.{foo,txt}", GLOB_BRACE), 1) ;
	echo '<br/>' ;
	echo '<strong>Remark</strong>: here the <code>printFiles()</code> function is invoked with a second dummy parameter (i.e. "1")<br/>' ;
	echo 'in order to print the absolute path of each result.<br/>' ;
	echo '<br/><hr/>' ;
	
	// 4. Invoking findFiles() with 2 parameters (using GLOB_BRACE option)
	echo '<strong>Searching files using the <code>GLOB_BRACE</code> option</strong> (2 different search patterns)<br/>' ;
	echo '<p>The <code>GLOB_BRACE</code> option can be used also to search a set of different search patterns.</p>' ;
	echo 'Command:<br/><br/>' ;
	echo '<code>printFiles( findFiles("{*ma*,??-find-files}.php", GLOB_BRACE), 1) ;</code><br/><br/>' ;
	echo 'Result:<br/><br/>' ;		
	printFiles( findFiles("{*ma*,??-find-files}.php", GLOB_BRACE), 1) ;
	echo '<br/>' ;
	echo 'Here the <code>GLOB_BRACE</code> option is used to search any file containing the string "<code>ma</code>" and any file<br/>' ;
	echo 'matching the "<code>??-find-files</code>", where "<code>??</code>" are the first two characters (holding any value)<br/>';
	echo '<br/><hr/>' ;

/*
* Looks file in the current directory, using a CASE-SENSITIVE search, more advanced that the
* basic "scandir()" directory (of the Directory extension). This is achieved using the "glob()"
* function of the Filesystem extension.
* For reference see:
* File System Related Extensions: http://www.php.net/manual/en/refs.fileprocess.file.php
* Directory Functions: http://www.php.net/manual/en/ref.dir.php
* Filesystem: http://www.php.net/manual/en/book.filesystem.php
*/
function findFiles() {

	$args = func_get_args() ;  
	switch(count($args)) {
		case 0 :	$result = "No arguments" ;					break ;
		case 1 :	$files = glob($args[0]) ;  					break ;
		case 2 :	$files = glob($args[0], $args[1]) ;  		break ;
		default:	$result = "Wrong argument" ;
	}
	return $files ;
}

/* 
* Just print the array passed as argument.
*/
function printFiles() {	

	$args = func_get_args() ;  
	if (count($args) == 2) $args[0] = array_map('realpath', $args[0]) ;
	if (count($args) > 0) {
		foreach ($args[0] as $i => $file) echo "File ".($i + 1).": $file<br/>" ;  
	}
}
?>

<p>References:</p>
<a href="http://www.php.net/manual/en/book.filesystem.php" title="Filesystem on php.net">Filesystem</a><br/>
<a href="http://www.php.net/manual/en/ref.dir.php" title="Directory Functions on php.net">Directory Functions</a><br/>
<a href="http://www.php.net/manual/en/refs.fileprocess.file.php" title="File System Related Extensions on php.net">File System Related Extensions</a><br/>

<?php include 'test_footer.php' ?>