<?php
	/**
	* This page receives the action from the "customers_list" page or the "customers_data" page.
	* In any case parameters are received through a HTML FORM, hence data are retrieved using the POST method.
	* Records chosen by the user are stored in INPUT fields named "record<n>": if the field is ON,
	* the "n-th" record has been selected. Then, two possibile pages can be targeted from here:
	*
	* - users_data.php: if the user chooses to modify the user (single record).
	* - users_delete.php: if the user chooses the delete the user (multiple selection).
	*
	*  In the first case data are passed through the HTTP request (GET method), in the second case data are passed
	*  as hidden INPUT fields of the HTML form, then the POST method will be involved.
	*/

	include '../include/session_header.php' ; 		// Including pages that take care of the session and database
	include '../include/database_header.php' ;		// Managing database connections
	include '../include/users_DAO.php' ;			// Including pages managing the users table (DAO layer)
	include '../include/display_header.php' ;		// Defining layout, images and loading the left menu

	// REFACTORED (14-09-2012)
	$customersWidth 	= getCustomersColumns() ;
	$customersName		= getCustomersHeaders() ;
?>

<script language="JavaScript">
function postForm() {
	document.deleteForm.submit() ;
}
// Appending the users CSS at run-time
linkElement 		= document.createElement("link") ;
linkElement.rel 	= "stylesheet" ;
linkElement.href 	= "../css/users.css" ;
document.head.appendChild(linkElement) ;
// jQuery section
$(document).ready( function() {
	$('#customer_table tr:odd').addClass('td_odd') ;
	$('#customer_table tr:even').addClass('td_even') ;
	$('#customer_table tr:first').removeClass('td_even') ;
}) ;
</script>

<?php
	// 1. Recognizing the action selected by the user
	// 1.1 Recognizing "view mode" (users or administrators)
	// DEPRECATED: in previous versions the "mode" parameter was passed using plain GET or POST (not Ajax)
	// if 		(isset( $_GET['mode']  	))		$mode = $_GET['mode'] ;
	// elseif 	(isset( $_POST['mode']	))		$mode = $_POST['mode'] ;
	// CURRENT MODE: retrieving the view mode from the HTTP session (set using an Ajax call)
	if ( isset($_SESSION['USER_VIEW']) ) 	$mode = $_SESSION['USER_VIEW'] ;
	// 1.2 Recognizing other operations
	if (isset($_POST['quest'])) $quest = $_POST['quest'] ; 	else $quest = 1 ;
	if 		($quest == 1) 		$operation = "MODIFICA" ;
	elseif 	($quest == 2) 		$operation = "CONFERMA CANCELLAZIONE" ;

	// 2. Customizing table layout
	$delta 		= 20 ;
	$columns 	= 7 ;
	$span		= $columns + 1 ;
	include	"../include/users_labels.php" ;
	print 	"<p class='td_customers_title'>$operation $labelTitle</p>" ;

	// 3. Identifying which records are affected by the operation
	$index = 0 ;
	$chosen = array() ;
	foreach ($_POST as $row => $value) if ($value == "on") {
		$begin = substr($row,0,6) ;
		if ($begin == "record") {
			$chosen[$index] = substr($row,6) ;
			$index++ ;
		}
		// Keep for testing or debug
		// print "($index) row: $row , value: $value<br/>" ;
	}
	// Keep for testing or debug
	// print_r(array_values($chosen)) ;

  // 4. Printing table only if data are available
	$total = count($chosen) ;
	if ($total >= 1) {
?>

<div id="customer_table">
<table>
<tr><td class="td_customers_title" colspan="<?php print "$span" ?>"><?php print "$labelName SELEZIONATI ($total)" ?></td></tr>
<tr>

<!-- This form is used only if the user chooses the DELETE option -->
<form name="deleteForm" action="users_delete.php" method="post">

<?php
	// PRINTING USERS TABLE
    // 1. Printing table headers, assigning "td width" considering field's length from the database
	foreach($customersName as $index => $caption) {
		$width = $delta*($customersWidth[$index]) ;
		print "\t<td width='$width px' class='td_customers_header'>$caption</td>\n" ;
		// Keep for testing or debug
		// print "\t<td width='$width px' class='td_customers_header'>$index-$customersWidth[$index]</td>\n" ;
	}
	print "</tr>" ;
    // 2. Tracking selected records (if DELETE option)
    if ($quest == 2) foreach ($chosen as $value) print "\t<input type='hidden' name='record$value' value='yes'>\n" ;
    // 3. Printing values
    $line = 0 ;
    $recordSet = getCustomersSelection($chosen) ;
	while ($row = mysql_fetch_array($recordSet, MYSQL_ASSOC)) {
		$index = 0 ;
		$line += 1 ;
		// Remark: the setting MYSQL_ASSOC is case-sensitive (with respect of the SQL statement)
		$code = $row["code"] ;
		print "<tr>\n" ;
		foreach ($row as $value) {
			$width = $delta*($customersWidth[$index]) ;
			if (isset($customersName[$index])) {
				print "\t<td width='$width px'>$value</td>\n" ;
			}
			$index += 1 ;
		}
		print "</tr>\n";
    } // End of while
?>

</table>
</div>

<br/>

<?php
	// Managing the selection (quest = 1 --> UPDATE, quest = 2 --> DELETE)
	print "\t<p class='td_customers_title'>" ;
	if ( ($total > 1 ) && ($quest == 1)	)	print "\t<span class='error'>Sono stati selezionati troppi $label_02: &egrave; necessario modificare un $label_01 alla volta!</span>" ;
	if ( ($total == 1) && ($quest == 1)	) 	print "\t<a class='confirm' href='users_data.php?code=$chosen[0]' title='$operation'>$operation</a>\n" ;
	if (  $quest == 2					) 	print "\t<a class='confirm' href='#' onclick='postForm()' title='$operation'>$operation</a>\n" ;
	print "\t</p>\n" ;
?>

<!-- If the target is "users_delete.php", data are passed within the form -->
<input type="hidden" name="quest" value="<?php print "$quest" ; ?>">

<?php
	// end of "if ($total >= 1)..."
	} else  {
		print "\t<p class='td_customers_title'>" ;
		print "\t<span class='error'>Non &egrave; stato selezionato alcun $label_01!</span>" ;
		print "\t</p>\n" ;
	}
	releaseAll() ;
?>

</form>

<br/><?php include 'users_goback.php' ;  ?><br/>

<?php include '../include/display_footer.php' ;  ?>